package com.pipipifa.pilaipiwang.goodselect.presenter

import com.pipipifa.pilaipiwang.goodselect.api.UselectSevice
import com.pipipifa.pilaipiwang.goodselect.model.*
import com.pipipifa.pilaipiwang.model.user.User
import com.pipipifa.pilaipiwang.net.Cmd
import com.pipipifa.pilaipiwang.presenter.base.BasePresenter
import com.pipipifa.pilaipiwang.presenter.base.BaseView
import com.ppwang.ppbase.base.net.ApiURLConfig
import com.ppwang.ppbase.base.net.param.MapServerValue
import com.ppwang.ppbase.base.net.parse.PPApi
import com.ppwang.ppbase.base.net.parse.ResponseData
import com.ppwang.ppbase.base.net.request.OkGoRequestUtil

interface UselectApplyRefundResultContrat {
    interface IView : BaseView {
        fun onLoadGoodsData(bean: UselectRefundGoodsBean)
        fun onLoadReasonDialogData(bean: UselectRefundReasonBean)
        fun onUpApplyRefundSuccess(bean: UselectApplyRefundBean)
        fun onUpApplyReplacement(bean:  IsUslectReplacementBean)
        fun onError(errorMessage: String)
    }

    class Presenter(iView: IView) : BasePresenter<IView>() {
        var requestUtil: OkGoRequestUtil

        init {
            mView = iView;
            requestUtil = OkGoRequestUtil()
        }

        override fun getRequest(): OkGoRequestUtil {
            return requestUtil
        }


        //获取退款商品的数据
        fun loadGoodsData(user: User, ppOrderId: String) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam51009(user, ppOrderId))
            requestUtil.post(ApiURLConfig.goodsUrl(), value) { response ->
                if (response.hasError()) {
                    mView.onError(response.errorMessage)
                } else {
                    val map = response.get()
                    var arrayRefundGoodsBean = map.get(Cmd.REQUEST_CODE_51009) as UselectRefundGoodsBean
                    if (null != arrayRefundGoodsBean) {
                        mView.onLoadGoodsData(arrayRefundGoodsBean)
                    }
                }
            }
        }


        //获取退款理由
        fun loadDialogData() {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam51002())
            requestUtil.post(ApiURLConfig.goodsUrl(), value) { response ->
                if (response.hasError()) {
                    mView.onError(response.errorMessage)
                } else {
                    val map = response.get()
                    var refundReason: UselectRefundReasonBean = map.get(Cmd.REQUEST_CODE_51002) as UselectRefundReasonBean
                    mView.onLoadReasonDialogData(refundReason)
                }
            }
        }

        //申请退款
        fun upApplyRefund(user: User, ppOrderId: String, refundType: Int, refundReasonTypeId: String, reason: String, proofImages: ArrayList<String>, refundGoods: ArrayList<UselectUpGoosBean>) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam51000(user, ppOrderId, refundType, refundReasonTypeId, reason, proofImages, refundGoods));
            requestUtil.post(ApiURLConfig.goodsUrl(), value) { response ->
                if (response.hasError()) {
                    mView.onError(response.errorMessage)
                } else {
                    val map = response.get()
                    var bean = map.get(Cmd.REQUEST_CODE_51000) as UselectApplyRefundBean
                    if (null != bean) {
                        mView.onUpApplyRefundSuccess(bean)
                    }
                }
            }
        }

        /**
         * 52000 优选|申请商品补发
         */
        fun upApplyReplacement(user: User, ppOrderId: String, reason: String, proofImages: ArrayList<String>) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam52000(user, ppOrderId, reason, proofImages))
            requestUtil.postRequest(ApiURLConfig.goodsUrl(), value, object : PPApi {
                override fun onResponse(response: ResponseData?) {
                    if (response!!.hasError()) {
                        mView.onError(response.errorMsg)
                    } else {
                        var bean = response.getData(Cmd.REQUEST_CODE_52000) as IsUslectReplacementBean
                        mView.onUpApplyReplacement(bean)
                    }
                }
            })
        }
    }
}