package com.pipipifa.pilaipiwang.goodselect.presenter

import com.hjq.toast.ToastUtils
import com.pipipifa.pilaipiwang.goodselect.api.UselectSevice
import com.pipipifa.pilaipiwang.goodselect.model.UselectReplacementDetailBean
import com.pipipifa.pilaipiwang.goodselect.model.UselectRefundDetailBean
import com.pipipifa.pilaipiwang.model.user.User
import com.pipipifa.pilaipiwang.net.Cmd
import com.pipipifa.pilaipiwang.presenter.base.BasePresenter
import com.pipipifa.pilaipiwang.presenter.base.BaseView
import com.ppwang.ppbase.base.net.ApiURLConfig
import com.ppwang.ppbase.base.net.param.MapServerValue
import com.ppwang.ppbase.base.net.parse.PPApi
import com.ppwang.ppbase.base.net.parse.ResponseData
import com.ppwang.ppbase.base.net.request.OkGoRequestUtil

interface UselectRefundDetailResultContrat {

    interface IView : BaseView {
        fun onLoadSuccess(bean: UselectRefundDetailBean)
        fun onLoadReplacementSuccess(detailBeanUselect: UselectReplacementDetailBean)
        fun onCancelRefund(type: Boolean)
        fun onCancelReplacement(type: Boolean)
        fun onConfirmGoods(type: Boolean)
        fun onLoadError(errorMsg: String)
    }

    class Presenter(iView: IView) : BasePresenter<IView>() {
        var requestUtil: OkGoRequestUtil

        init {
            mView = iView;
            requestUtil = OkGoRequestUtil()
        }

        override fun getRequest(): OkGoRequestUtil {
            return requestUtil
        }


        fun loadData(user: User, refundType: Int, ppOrderId: String) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam51001(user, refundType, ppOrderId!!))
            requestUtil.post(ApiURLConfig.goodsUrl(), value) { response ->
                if (response.hasError()) {
                    mView.onLoadError(response.errorMsg)
                } else {
                    val map = response.get()
                    if (null != map) {
                        var bean: UselectRefundDetailBean = map.get(Cmd.REQUEST_CODE_51001) as UselectRefundDetailBean
                        mView.onLoadSuccess(bean)
                    }
                }
            }
        }


        /**
         * 撤销退款申请
         */
        fun cancelRefund(user: User, ppOrderId: String) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam51005(user, ppOrderId!!))
            requestUtil.post(ApiURLConfig.goodsUrl(), value) { response ->
                if (response.hasError()) {
                    mView.onLoadError(response.errorMsg)
                } else {
                    val map = response.get()
                    var data = map.get(Cmd.REQUEST_CODE_51005)
                    if (data as Boolean) {
                        mView.onCancelRefund(data)
                    }
                }
            }
        }

        fun undoArbitrationApply(user: User, ppOrderId: String) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam51101(user, ppOrderId!!))
            requestUtil.post(ApiURLConfig.goodsUrl(), value) { response ->
                if (response.hasError()) {
                    ToastUtils.show(response.errorMessage)
                } else {
                    val map = response.get()
                    var data = map.get(Cmd.REQUEST_CODE_51101)
                    if (data as Boolean) {
                        mView.onCancelRefund(data)
                    }
                }
            }
        }


        /**
         * 52002 优选|商品补发详情
         */
        fun loadReplacement(user: User, refundType: Int, replacementid: String) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam52002(user, refundType, replacementid!!))
            requestUtil.postRequest(ApiURLConfig.goodsUrl(), value, object : PPApi {
                override fun onResponse(response: ResponseData?) {
                    if (response!!.hasError()) {
                        mView.onLoadError(response.errorMsg)
                    } else {
                        var bean = response.getData(Cmd.REQUEST_CODE_52002) as UselectReplacementDetailBean
                        mView.onLoadReplacementSuccess(bean)
                    }
                }
            })
        }

        /**
         * 52003 优选|商品补发-申请取消商品补发
         */
        fun cancelReplacement(user: User, replacementId: String) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam52003(user, replacementId!!))
            requestUtil.postRequest(ApiURLConfig.goodsUrl(), value, object : PPApi {
                override fun onResponse(response: ResponseData?) {
                    if (response!!.hasError()) {
                        mView.onLoadError(response.errorMsg)
                    } else {
                        var bean = response.getData(Cmd.REQUEST_CODE_52003) as Boolean
                        mView.onCancelReplacement(bean)
                    }
                }
            })
        }

        /**
         * 52004 优选|商品补发-确认收货
         */
        fun confirmGoods(user: User, replacementId: String) {
            var value = MapServerValue()
            value.addValue(UselectSevice.creatParam52004(user, replacementId!!))
            requestUtil.postRequest(ApiURLConfig.goodsUrl(), value, object : PPApi {
                override fun onResponse(response: ResponseData?) {
                    if (response!!.hasError()) {
                        mView.onLoadError(response.errorMsg)
                    } else {
                        var bean = response.getData(Cmd.REQUEST_CODE_52004) as Boolean
                        mView.onConfirmGoods(bean)
                    }
                }
            })
        }
    }
}