package com.pipipifa.pilaipiwang.goodselect.ui.fragment

import android.content.Context
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.hjq.toast.ToastUtils
import com.pipipifa.pilaipiwang.AccountManager
import com.pipipifa.pilaipiwang.R
import com.pipipifa.pilaipiwang.goodselect.model.UselectReplacementListBean
import com.pipipifa.pilaipiwang.goodselect.model.UselectReplacementOrderNum
import com.pipipifa.pilaipiwang.goodselect.presenter.UselectReplacementListResultContrat
import com.pipipifa.pilaipiwang.goodselect.ui.activity.refund.UselectRefundDetailActivity
import com.pipipifa.pilaipiwang.goodselect.ui.activity.refund.UselectReplacementActivity
import com.pipipifa.pilaipiwang.goodselect.ui.adapter.UselectReplacemertAdapter
import com.pipipifa.pilaipiwang.model.eventbus.ReplacementEventMessage
import com.pipipifa.pilaipiwang.presenter.base.BaseMvpFragment
import com.pipipifa.pilaipiwang.presenter.user.LoginPresenter
import com.ppwang.uikit.widget.multilayout.PUIMultiStatesLayout
import com.scwang.smartrefresh.layout.SmartRefreshLayout
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnLoadMoreListener
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode

/**
 * @author: wangben
 * @date: 2020/4/17
 */
class UselectReplacemertFragment : BaseMvpFragment<UselectReplacementListResultContrat.Presenter>(), UselectReplacementListResultContrat.IView, OnRefreshListener, OnLoadMoreListener {
    lateinit var mMultiStatusLayout: PUIMultiStatesLayout
    lateinit var mListView: RecyclerView
    lateinit var mAdapter: UselectReplacemertAdapter
    lateinit var mRefreshLayout: SmartRefreshLayout
    var stutas: Int = 0;
    var page = 1

    companion object {
        private val REPLACEMERT_TYPE = "replacemert_type"
        @JvmStatic
        fun newInstance(refundType: Int): Fragment {
            val fragment = UselectReplacemertFragment()
            val bundle = Bundle()
            bundle.putInt(REPLACEMERT_TYPE, refundType)
            fragment.arguments = bundle
            return fragment
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        registerEventBus()
        if (arguments != null) {
            stutas = arguments!!.getInt(REPLACEMERT_TYPE, -1)
        }
        mPresenter = UselectReplacementListResultContrat.Presenter(this)
    }

    override fun onResume() {
        super.onResume()
        if (null != mPresenter) {
            var user = AccountManager.getInstance().user
            if (null != user) {
                mPresenter.loadReplacemertList(user, "${stutas}", page)
            } else {
                LoginPresenter.getLoginIntent(activity, false)
            }
        }
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        var view = inflater.inflate(R.layout.fragment_uselect_replacemert_list, null)
        initViews(view)
        mMultiStatusLayout.showLoadingLayout()
        return view
    }

    fun initViews(view: View) {
        mRefreshLayout = view.findViewById(R.id.refresh_replacemert)
        mRefreshLayout.setOnRefreshListener(this).setOnLoadMoreListener(this)
        mListView = view.findViewById(R.id.refund_list)
        mMultiStatusLayout = view.findViewById(R.id.multistatus_layout)
        mAdapter = UselectReplacemertAdapter()
        mListView.layoutManager = LinearLayoutManager(activity)
        mListView.adapter = mAdapter

        mAdapter.setOnItemClickListener { adapter, view, position ->
            var bean = mAdapter.data.get(position)
            startActivity(UselectRefundDetailActivity.getRefundId(activity as Context, bean.replacementId, bean.orderId, 0))
        }
    }

    override fun onError(errorMsg: String) {
        ToastUtils.show(errorMsg)
        setRefreshState()
    }

    override fun onNullData() {
        setRefreshState()
    }

    override fun onLoadSuccess(list: ArrayList<UselectReplacementOrderNum>) {
        val activity = getActivity() as UselectReplacementActivity?
        if (null != activity) {
            activity.getOrderNum(list)
        }
    }

    override fun onReplacemertList(bean: ArrayList<UselectReplacementListBean>) {
        if (page == 1) {
            mAdapter.setNewData(bean)
        } else {
            mAdapter.addData(bean)
        }
        setRefreshState()
    }


    override fun onRefresh(refreshLayout: RefreshLayout) {
        page = 1
        if (null != mPresenter) {
            var user = AccountManager.getInstance().user
            if (null != user) {
                mPresenter.loadReplacemertList(user, "${stutas}", page)
            } else {
                LoginPresenter.getLoginIntent(activity, false)
            }
        }
    }

    override fun onLoadMore(refreshLayout: RefreshLayout) {
        page++
        if (null != mPresenter) {
            var user = AccountManager.getInstance().user
            if (null != user) {
                mPresenter.loadReplacemertList(user, "${stutas}", page)
            } else {
                LoginPresenter.getLoginIntent(activity, false)
            }
        }
    }

    private fun setRefreshState() {
        mRefreshLayout.finishRefresh()
        mRefreshLayout.finishLoadMore()
        if (mAdapter.data.size > 0) {
            mMultiStatusLayout.showContentLayout()
        } else {
            mMultiStatusLayout.showEmptyLayout()

        }
        mAdapter.notifyDataSetChanged()
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    fun onEventMainThread(event: ReplacementEventMessage?) {
        if (event != null && event.getType() == ReplacementEventMessage.TYPE_CARD_DELETE) {
            val mDeletedReplacementid = event.getData()
            for (i in 0 until mAdapter.data.size){
                if (mDeletedReplacementid.equals(mAdapter.data.get(i).replacementId)){
                    mAdapter.data.removeAt(i)
                    break
                }
            }
            mAdapter.notifyDataSetChanged()
        }
    }
}