package com.pipipifa.pilaipiwang.net.okgo

import android.text.TextUtils
import com.apputil.net.ApiListener
import com.apputil.net.ApiResponse
import com.google.gson.Gson
import com.lzy.okgo.callback.AbsCallback
import com.lzy.okgo.model.Response
import com.pipipifa.pilaipiwang.model.Data
import com.ppwang.ppbase.base.net.param.MapServerValue
import com.ppwang.ppbase.base.net.param.ServerValue
import org.json.JSONObject

/**
 * Anthor: 李东益
 * Date：2020/3/3
 * Description:
 */
class JsonParseData(param: MapServerValue, listener: ApiListener<HashMap<String, Data>>) : AbsCallback<HashMap<String, Data>>() {

    private var apiResponse = ApiResponse<HashMap<String, Data>>()
    private var param: MapServerValue
    private var listener: ApiListener<HashMap<String, Data>>

    init {
        this.param = param
        this.listener = listener
    }

    override fun onSuccess(response: Response<HashMap<String, Data>>?) {
        if (response != null) {
            apiResponse.setResponse(response.body())
        }
        if (listener != null) {
            listener.onResponse(apiResponse)
        }
    }

    override fun onCacheSuccess(response: Response<HashMap<String, Data>>?) {
        super.onCacheSuccess(response)
        if (response != null) {
            apiResponse.setResponse(response.body())
        }
        if (listener != null) {
            listener.onResponse(apiResponse)
        }
    }

    override fun onError(response: Response<HashMap<String, Data>>?) {
        super.onError(response)
        if (response != null) {
            apiResponse.setError(response.exception as Exception?)
            apiResponse.setResponse(HashMap<String, Data>())
        }
        if (listener != null) {
            listener.onResponse(apiResponse)
        }
    }

    override fun convertResponse(response: okhttp3.Response?): HashMap<String, Data> {
        var map = HashMap<String, Data>()
        if (response != null) {
            var code = response.code()
            var jsonContent = response.body()?.string()
            if (!TextUtils.isEmpty(jsonContent) && param != null) {
                var list = param.serverValues
                var jobj = JSONObject(jsonContent)
                var gson = Gson()
                if (list != null) {
                    for (item: ServerValue in list) {
                        var cmdObj = jobj.getString(item.cmd)
                        var data: Data = gson.fromJson(cmdObj, item.dataType)
                        map.put(item.cmd, data)
                    }
                }
            }
        } else {
            apiResponse.setError(IllegalStateException("网络请求出现异常"))
        }
        return map
    }

}