package com.pipipifa.pilaipiwang.presenter.seller

import com.apputil.net.ApiListener
import com.hjq.toast.ToastUtils
import com.pipipifa.pilaipiwang.model.buyer.OrderGoods
import com.pipipifa.pilaipiwang.model.order.ShipmentsBean
import com.pipipifa.pilaipiwang.model.shopcar.Order
import com.pipipifa.pilaipiwang.model.user.User
import com.ppwang.ppbase.base.net.ApiURLConfig
import com.pipipifa.pilaipiwang.net.Cmd
import com.pipipifa.pilaipiwang.net.OrderApi
import com.pipipifa.pilaipiwang.net.UserServerApi
import com.pipipifa.pilaipiwang.presenter.base.BasePresenter
import com.pipipifa.pilaipiwang.presenter.base.BaseView
import com.ppwang.ppbase.utils.ArrayUtil
import com.ppwang.ppbase.base.net.param.MapServerValue
import com.ppwang.ppbase.base.net.request.OkGoRequestUtil

/**
 * Anthor: 李东益
 * Date：2020/2/25
 * Description:
 */
interface SearchQrCodeOrderResultContrat {

    interface IView : BaseView {
        /**
         * 加载数据
         */
        fun onLoadWaitData(list: ArrayList<OrderGoods>, orderMap: Map<String, Order>, waitCount: Int)

        fun onLoadOtherData(other: ArrayList<OrderGoods>, orderMap: Map<String, Order>, otherSize: Int)

        /**
         * 空状态，没有数据时调用
         */
        fun onEmptyView()

        /**
         * 发货状态
         */
        fun onSendGoodsStatus(result: Boolean)
    }

    /**
     * 相当于java 的final class
     */
    class Presenter(iView: IView) : BasePresenter<IView>() {

        private var requestUtil: OkGoRequestUtil

        init {
            mView = iView;
            requestUtil = OkGoRequestUtil()
        }

        override fun getRequest(): OkGoRequestUtil {
            return requestUtil
        }

        /**
         * 发货
         */
        fun commit(user: User, order: Order) {
            val params = MapServerValue()
            params.addValue(UserServerApi.createRequest6540(user, order))
            requestUtil.get(ApiURLConfig.goodsUrl(), params, ApiListener {
                mView.onDismissDialog()
                if (it.hasError()) {
                    ToastUtils.show(it.errorMessage)
                } else {
                    var map = it.get()
                    if (map != null) {
                        var result = map.get(Cmd.REQUEST_CODE_6540)
                        if (result is Boolean) {
                            mView.onSendGoodsStatus(result)
                        } else {
                            mView.onSendGoodsStatus(false)
                        }
                    }
                }
            })
            mView.onShowDialog("请求中...")
        }

        fun handleData(bean: ShipmentsBean) {
            var waitList = ArrayList<OrderGoods>()
            var waitMap = HashMap<String, Order>()
            if (!ArrayUtil.isEmpty(bean.undeliveredOrder)) {
                for (item in bean.undeliveredOrder) {
                    waitMap.put(item.orderId, item)
                    waitList.addAll(item.orderGoods)
                }
            }
            mView.onLoadWaitData(waitList, waitMap, bean.undeliveredOrderLimit)

            var otherList = ArrayList<OrderGoods>()
            var otherMap = HashMap<String, Order>()
            if (!ArrayUtil.isEmpty(bean.otherOrder)) {
                for (item in bean.otherOrder) {
                    otherMap.put(item.orderId, item)
                    otherList.addAll(item.orderGoods)
                }
            }
            mView.onLoadOtherData(otherList, otherMap, bean.otherOrderLimit)
        }

        /**
         * 加载数据，待发货的订单
         */
        fun loadData(user: User, code: String) {
            var params = MapServerValue()
            params.addValue(OrderApi.createRequest6550(user, code))
            requestUtil.get(ApiURLConfig.goodsUrl(), params, ApiListener {
                //    mView.onDismissDialog()
                if (it.hasError()) {
                    ToastUtils.show(it.errorMessage)
                } else {
                    var map = it.get()
                    var data = map.get(Cmd.REQUEST_CODE_6550)
                    if (data is ShipmentsBean) {
                        handleData(data)
                    } else {
                        mView.onEmptyView()
                    }
                }
            })
        }
    }

}