package com.pipipifa.pilaipiwang.presenter.user

import com.apputil.net.ApiListener
import com.hjq.toast.ToastUtils
import com.pipipifa.pilaipiwang.model.user.AccountRule
import com.pipipifa.pilaipiwang.model.user.ChildAccount
import com.pipipifa.pilaipiwang.model.user.ChildAccountRule
import com.pipipifa.pilaipiwang.model.user.User
import com.ppwang.ppbase.base.net.ApiURLConfig
import com.pipipifa.pilaipiwang.net.Cmd
import com.pipipifa.pilaipiwang.net.UserServerApi
import com.pipipifa.pilaipiwang.presenter.base.BasePresenter
import com.pipipifa.pilaipiwang.presenter.base.BaseView
import com.ppwang.ppbase.utils.ArrayUtil
import com.ppwang.ppbase.base.net.param.MapServerValue
import com.ppwang.ppbase.base.net.request.OkGoRequestUtil

/**
 * Anthor: 李东益
 * Date：2020/2/20
 * Description:
 */
class AddChildAccountContract {

    interface IView : BaseView {
        /**
         * 获取验证码
         */
        fun onRequestCode(result: Boolean)

        /**
         * 角色
         */
        fun onLoadRuleList(rules: ArrayList<AccountRule>)

        /**
         * childAccountRule 所有的权限
         * hasList 已经拥有的权限
         */
        fun onLoadChildAccountRuleList(childAccountRule: ArrayList<ChildAccountRule>?, hasList: ArrayList<ChildAccountRule>?)

        /**
         * 编辑子账号的返回状态，对应的cmd是11609
         */
        fun onEditAccountStatus(result: Boolean)

        /**
         * 删除子账号
         */
        fun onDeleteAccount(result: Boolean);

        /**
         * 添加子账号状态
         */
        fun onAddChildStatus(result: Boolean);

    }

    class Presenter(iView: IView) : BasePresenter<IView>() {

        private var request: OkGoRequestUtil;
        private var iView: IView;

        init {
            this.request = OkGoRequestUtil();
            this.iView = iView
        }

        override fun getRequest(): OkGoRequestUtil {
            return request;
        }

        fun loadData(user: User, childAccount: ChildAccount?) {
            var params = MapServerValue()
            params.addValue(UserServerApi.createRequset11607(user))
            if (childAccount == null) {
                params.addValue(UserServerApi.createRequest11611(user, null))
            } else {
                params.addValue(UserServerApi.createRequest11611(user, childAccount.userId))
                params.addValue(UserServerApi.createRequest11608(user, childAccount))
            }
            iView.onShowDialog(null)
            getRequest().post(ApiURLConfig.goodsUrl(), params, ApiListener {
                iView.onDismissDialog()
                if (it.hasError()) {
                    ToastUtils.show(it.errorMessage)
                } else {
                    var map: HashMap<String, Any> = it.get()
                    if (map != null) {
                        /**
                         * 角色权限
                         */
                        var childAccountRule = map.get(Cmd.REQUEST_CODE_11607) as ArrayList<ChildAccountRule>
                        /**
                         * 角色
                         */
                        var accountRule = map.get(Cmd.REQUEST_CODE_11611) as ArrayList<AccountRule>

                        if (!ArrayUtil.isEmpty(accountRule)) {
                            iView.onLoadRuleList(accountRule)
                        }

                        var list = map.get(Cmd.REQUEST_CODE_11608)
                        var permissList = ArrayList<ChildAccountRule>()
                        if (list != null) {
                            var permissStringList = list as ArrayList<String>
                            if (!ArrayUtil.isEmpty(permissStringList)) {
                                for (item in permissStringList) {
                                    if (item != null) {
                                        permissList.add(ChildAccountRule(item.toInt()))
                                    }
                                }
                            }
                        }
                        iView.onLoadChildAccountRuleList(childAccountRule, permissList)
                    }
                }
            })
        }

        fun editAccount(user: User, account: ChildAccount, selectPermissionList: ArrayList<ChildAccountRule>, currentRule: AccountRule) {
            var params = MapServerValue()
            params.addValue(UserServerApi.createRequest11609(user, account, selectPermissionList, currentRule))
            getRequest().post(ApiURLConfig.goodsUrl(), params, ApiListener {
                iView.onDismissDialog()
                if (it.hasError()) {
                    ToastUtils.show(it.errorMessage)
                } else {
                    var map = it.get();
                    if (map != null) {
                        var result = map.get(Cmd.REQUEST_CODE_11609);
                        if (result != null) {
                            iView.onEditAccountStatus(result as Boolean)
                        } else {
                            iView.onEditAccountStatus(false)
                        }
                    }
                }
            })
            iView.onShowDialog("提交中...")
        }

        fun deleteAccount(user: User, account: ChildAccount) {
            var params = MapServerValue()
            params.addValue(UserServerApi.createReqest11604(user, account))
            getRequest().post(ApiURLConfig.goodsUrl(), params, ApiListener {
                iView.onDismissDialog()
                if (it.hasError()) {
                    ToastUtils.show(it.errorMessage)
                } else {
                    var map = it.get();
                    if (map != null) {
                        var result = map.get(Cmd.REQUEST_CODE_11604)
                        if (result != null) {
                            iView.onDeleteAccount(result as Boolean);
                        } else {
                            iView.onDeleteAccount(false);
                        }
                    }
                }
            })
            iView.onShowDialog("删除中...")

        }

        fun commit(user: User, phoneMob: String, selectPermissionList: ArrayList<ChildAccountRule>, currentRule: AccountRule, code: String) {
            // 提交数据
            var params = MapServerValue()
            params.addValue(UserServerApi.createRequest11598(user, phoneMob, selectPermissionList, currentRule, code))
            getRequest().post(ApiURLConfig.goodsUrl(), params, ApiListener {
                iView.onDismissDialog()
                if (it.hasError()) {
                    ToastUtils.show(it.errorMessage)
                } else {
                    var data = it.get()
                    if (data != null) {
                        var data11598 = data.get(Cmd.REQUEST_CODE_11598)
                        if (data11598 != null) {
                            iView.onAddChildStatus(data11598 as Boolean)
                        } else {
                            iView.onAddChildStatus(false)
                        }
                    }
                }
            })
            iView.onShowDialog("发送中...")
        }

        /**
         * 请求发送验证码
         */
        fun requestVerificaCode(user: User, phoneNumber: String) {
            var params = MapServerValue();
            params.addValue(UserServerApi.createRequest11599(user, phoneNumber))
            getRequest().post(ApiURLConfig.goodsUrl(), params, ApiListener {
                if (it.hasError()) {
                    ToastUtils.show(it.errorMessage)
                    iView.onRequestCode(false)
                } else {
                    var data = it.get();
                    if (data != null) {
                        var result = data.get(Cmd.REQUEST_CODE_11599)
                        if (result != null) {
                            iView.onRequestCode(result as Boolean)
                        } else {
                            iView.onRequestCode(false)
                        }
                    }
                }
            })
        }
    }
}