package com.pipipifa.pilaipiwang.ui.activity.seller

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.os.Handler
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentManager
import androidx.fragment.app.FragmentPagerAdapter
import com.flyco.tablayout.listener.CustomTabEntity
import com.flyco.tablayout.listener.OnTabSelectListener
import com.hjq.toast.ToastUtils
import com.pipipifa.pilaipiwang.AccountManager
import com.pipipifa.pilaipiwang.R
import com.pipipifa.pilaipiwang.model.buyer.OrderGoods
import com.pipipifa.pilaipiwang.model.eventbus.PPEventMessage
import com.pipipifa.pilaipiwang.model.shopcar.Order
import com.pipipifa.pilaipiwang.model.view.TabEntity
import com.pipipifa.pilaipiwang.presenter.base.BaseMvpActivity
import com.pipipifa.pilaipiwang.presenter.seller.SearchQrCodeOrderResultContrat
import com.pipipifa.pilaipiwang.ui.fragment.seller.SearchQrCodeOrderResultFragment
import com.pipipifa.pilaipiwang.ui.view.Topbar
import com.pipipifa.pilaipiwang.ui.view.flycotablayout.ExCommonTabLayout
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode


/**
 * Anthor: 李东益
 * Date：2020/2/25
 * Description:
 */
class SearchQrCodeOrderResultActivity : BaseMvpActivity<SearchQrCodeOrderResultContrat.Presenter>(), SearchQrCodeOrderResultContrat.IView {

    private lateinit var code: String
    private lateinit var viewPager: androidx.viewpager.widget.ViewPager
    private lateinit var topbar: Topbar
    private lateinit var tabLayout: ExCommonTabLayout
    private lateinit var adapter: PageAdapter
    private var fragments = ArrayList<androidx.fragment.app.Fragment>()
    private var handler = Handler();
    private var arr = arrayListOf<CustomTabEntity>()
    private var otherSize: Int = 0

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_search_code_order_result);
        init()
        EventBus.getDefault().register(this)
    }

    fun getOtherSize(): Int {
        return otherSize
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    fun onEventMainThread(event: PPEventMessage<*>?) {
        if (event != null && event.type == MESSAGE_EVENT_TYPE_SEND_GOODS) {
            var user = AccountManager.getInstance().user;
            if (user == null) {
                ToastUtils.show("请先登录再操作")
                return
            }
            var order = event.data
            if (user != null && order is Order) {
                mPresenter.commit(user, order)
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        EventBus.getDefault().unregister(this)
    }

    private fun init() {

        mPresenter = SearchQrCodeOrderResultContrat.Presenter(this);

        code = getIntent().getStringExtra(PARAM_CODE)

        tabLayout = findViewById(R.id.tab_layout);
        viewPager = findViewById(R.id.vp_search_code_result);
        topbar = findViewById(R.id.topbar);
        topbar.setCenterContent("搜索结果")

        arr.add(TabEntity("待发货订单(0)", 0, 0))
        arr.add(TabEntity("其他订单(0)", 0, 0))

        fragments.add(SearchQrCodeOrderResultFragment.newInstance(0))
        fragments.add(SearchQrCodeOrderResultFragment.newInstance(1))

        tabLayout.setTabData(arr)
        adapter = PageAdapter(supportFragmentManager)
        viewPager.adapter = adapter

        var user = AccountManager.getInstance().user
        if (user != null) {
            mPresenter.loadData(user, code)
        }

        tabLayout.setOnTabSelectListener(object : OnTabSelectListener {
            override fun onTabSelect(position: Int) {
                viewPager.setCurrentItem(position)
            }

            override fun onTabReselect(position: Int) {
            }
        })

        viewPager.addOnPageChangeListener(object : androidx.viewpager.widget.ViewPager.OnPageChangeListener {
            override fun onPageScrollStateChanged(p0: Int) {
            }

            override fun onPageScrolled(p0: Int, p1: Float, p2: Int) {

            }

            override fun onPageSelected(p0: Int) {
                tabLayout.currentTab = p0
            }

        })

    }

    companion object {
        private var PARAM_CODE = "code"
        val MESSAGE_EVENT_TYPE_SEND_GOODS = 1;
        fun getIntent(context: Context, code: String): Intent {
            var intent = Intent(context, SearchQrCodeOrderResultActivity::class.java)
            intent.putExtra(PARAM_CODE, code)
            return intent;
        }
    }

    inner class PageAdapter(fm: FragmentManager?) : FragmentPagerAdapter(fm!!) {
        override fun getItem(p0: Int): Fragment {
            return fragments.get(p0)
        }

        override fun getCount(): Int {
            return fragments.size
        }

    }

    override fun onLoadWaitData(list: ArrayList<OrderGoods>, orderMap: Map<String, Order>, waitCount: Int) {
        handler.postDelayed(Runnable {
            var fragment = fragments.get(0) as SearchQrCodeOrderResultFragment;
            fragment.updateData(list, orderMap)
        }, 300)
        arr.clear()
        arr.add(TabEntity(String.format("待发货订单(%d)", waitCount), 0, 0))

    }

    override fun onLoadOtherData(other: ArrayList<OrderGoods>, orderMap: Map<String, Order>, otherSize: Int) {
        handler.postDelayed(Runnable {
            var fragment = fragments.get(1) as SearchQrCodeOrderResultFragment;
            fragment.updateData(other, orderMap)
        }, 300)
        arr.add(TabEntity(String.format("其他订单(%d)", otherSize), 0, 0))
        tabLayout.setTabData(arr)
        tabLayout.notifyDataSetChanged()
        this.otherSize = otherSize
    }

    override fun onEmptyView() {
        handler.postDelayed(Runnable {
            var fragmentWait = fragments.get(0) as SearchQrCodeOrderResultFragment;
            fragmentWait.updateData(ArrayList(), HashMap())

            var fragmentOther = fragments.get(1) as SearchQrCodeOrderResultFragment;
            fragmentOther.updateData(ArrayList(), HashMap())
        }, 300)
    }

    override fun onSendGoodsStatus(result: Boolean) {
        if (result) {
            ToastUtils.show("发货成功")
            finish()
        }
    }

}