package com.pipipifa.pilaipiwang.ui.fragment.seller

import android.os.Bundle
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.chad.library.adapter.base.BaseQuickAdapter
import com.pipipifa.pilaipiwang.R
import com.pipipifa.pilaipiwang.model.buyer.OrderGoods
import com.pipipifa.pilaipiwang.model.eventbus.PPEventMessage
import com.pipipifa.pilaipiwang.model.shopcar.Order
import com.pipipifa.pilaipiwang.ui.activity.order.RefundFreightActivity
import com.pipipifa.pilaipiwang.ui.activity.seller.SearchQrCodeOrderResultActivity
import com.pipipifa.pilaipiwang.ui.activity.seller.SellerOrderDetailActivity
import com.pipipifa.pilaipiwang.ui.activity.seller.SellerStockoutActivity
import com.pipipifa.pilaipiwang.ui.activity.seller.SendSignalActivity
import com.pipipifa.pilaipiwang.ui.adapter.search.SalesNewOrderAdapter
import com.pipipifa.pilaipiwang.ui.dialog.common.DefaultDialog
import com.pipipifa.pilaipiwang.ui.fragment.SalesOrderFragment
import com.pipipifa.pilaipiwang.ui.fragment.main.LazyFragment
import com.ppwang.ppbase.base.ui.view.loadview.LoadingLayout
import com.ppwang.ppbase.utils.ArrayUtil
import com.pipipifa.util.StringUtil
import org.greenrobot.eventbus.EventBus
import java.util.*
import kotlin.collections.ArrayList

/**
 * Anthor: 李东益
 * Date：2020/2/25
 * Description:
 */
class SearchQrCodeOrderResultFragment : LazyFragment(), BaseQuickAdapter.OnItemClickListener {

    private lateinit var recycleView: androidx.recyclerview.widget.RecyclerView
    private var type: Int = 0
    /**
     * orderGoods
     */
    private val orderGoods = ArrayList<OrderGoods>()
    /**
     * key:orderId,value:order
     */
    private val buyerOrders = LinkedHashMap<String, Order>()
    private lateinit var adapter: SalesNewOrderAdapter

    private lateinit var loadingLayout: LoadingLayout

    private lateinit var emptyLayout: View

    private val REQUEST_CODE_UPDATE = 1

    override fun lazyLoad() {

    }

    private fun createEmpptyView(inflater: LayoutInflater) {
        emptyLayout = inflater.inflate(R.layout.empty_center_layout, null)
        var image = emptyLayout.findViewById<ImageView>(R.id.iv_empty);
        image.setImageResource(R.drawable.icon_empty_order)
        emptyLayout.findViewById<TextView>(R.id.tv_empty).setText("暂无订单")
    }

    override fun onLoadView(inflater: LayoutInflater?): View? {

        var bundle = arguments
        if (bundle != null) {
            type = bundle.getInt(PARAM_TYPE)
        }

        loadingLayout = LoadingLayout(context)
        if (inflater != null) {
            createEmpptyView(inflater)
            loadingLayout.setEmptyView(emptyLayout)
        }
        var view = inflater?.inflate(R.layout.fragment_search_qrcode_order_result, null, false)
        loadingLayout.setContentView(view)

        recycleView = view?.findViewById<androidx.recyclerview.widget.RecyclerView>(R.id.ex_pull_recycle_view)!!
        recycleView.layoutManager = androidx.recyclerview.widget.LinearLayoutManager(context, androidx.recyclerview.widget.LinearLayoutManager.VERTICAL, false)
        adapter = SalesNewOrderAdapter(context as SearchQrCodeOrderResultActivity, orderGoods, buyerOrders)
        adapter.setNeedSendBtn(false)
        recycleView.adapter = adapter

        if (type == 0) {
            view.findViewById<View>(R.id.pui_tv_send_goods).visibility = View.VISIBLE
            view.findViewById<View>(R.id.pui_tv_send_goods).setOnClickListener {
                showDefaultDialog()
            }
        } else {
            view.findViewById<View>(R.id.pui_tv_send_goods).visibility = View.GONE
        }
        initListener()
        loadingLayout.showLoading()
    //    showDefaultDialog();
        return loadingLayout
    }

    private fun initListener() {
        adapter.setOnItemClickListener(this)
        adapter.setOnSalesOrderListener(object : SalesNewOrderAdapter.OnSalesOrderListener {
            override fun setSendSignal(orderId: String) {
                val intent = SendSignalActivity.getIntent(activity, orderId)
                startActivityForResult(intent, REQUEST_CODE_UPDATE)
            }

            override fun setLoadOrderDetail(orderId: String) {
                //   loadOrderDetail(orderId)
            }

            override fun setPrint(order: Order) {
                //    print(order)
            }

            override fun setStockout(orderGoods: OrderGoods, order: Order) {
                SalesOrderFragment.isTag = true
                SalesOrderFragment.isClickStockout = true
                startActivity(SellerStockoutActivity.getIntent(activity, orderGoods, order))
            }

            override fun setSortingStype(storeId: String, orderId: String) {
                startActivity(RefundFreightActivity.getFreight(activity, storeId, orderId, 0))
            }
        })
    }

    private fun showDefaultDialog() {
        var dialog = DefaultDialog(context)

        var okMessage = "";
        var message: CharSequence = ""
        if (activity is SearchQrCodeOrderResultActivity) {
            var size = (activity as SearchQrCodeOrderResultActivity).getOtherSize();
            if (size > 0) {
                var content = String.format("该物流单号有[%d]张异常状态订单" +
                        "<br>您可以选择等待异常订单结束后再发货" +
                        "<br>您可以先发待发货的订单，待异常订单恢复正常后再重新打单发货", size)
                message = StringUtil.formatColor(content, "#FF4B60")
                okMessage = "仍然发货"
            } else {
                message = "是否确认发货"
                okMessage = "确定"
            }
        }
        dialog.setMessage(message)
        dialog.setOkButton(okMessage, View.OnClickListener {
            dialog.dismiss()
            if (!ArrayUtil.isEmpty(orderGoods)) {
                var orderGoods = orderGoods.get(0);
                var order = buyerOrders.get(orderGoods.orderId)
                if (order != null) {
                    var eventMessage = PPEventMessage<Order>(SearchQrCodeOrderResultActivity.MESSAGE_EVENT_TYPE_SEND_GOODS, order);
                    EventBus.getDefault().post(eventMessage)
                }
            }
        })
        dialog.setCancelButton("取消", View.OnClickListener {
            dialog.dismiss()
        })
        dialog.hideTitle()
        dialog.show()
    }

    fun updateData(list: ArrayList<OrderGoods>, orderMap: Map<String, Order>) {
        if (!isAdded) {
            return
        }
        if (ArrayUtil.isEmpty(list)) {
            // 显示空状态页
            loadingLayout.showEmptyView()
        } else {
            orderGoods.addAll(list)
            loadingLayout.showContent()
        }

        if (orderMap != null) {
            buyerOrders.putAll(orderMap)
        }

        adapter.notifyDataSetChanged()
    }

    companion object {
        private val PARAM_TYPE = "type"
        fun newInstance(type: Int): SearchQrCodeOrderResultFragment {
            var fragmet = SearchQrCodeOrderResultFragment()
            var bundle = Bundle()
            bundle.putInt(PARAM_TYPE, type)
            fragmet.arguments = bundle
            return fragmet
        }
    }

    override fun onItemClick(adapter: BaseQuickAdapter<*, *>?, view: View?, position: Int) {
        val goods = orderGoods[position]
        val order = buyerOrders.get(goods.orderId)
        val intent = SellerOrderDetailActivity.getIntent(context, order)
        startActivity(intent)
    }

}
