package com.pipipifa.pilaipiwang.ui.view.lottieview

import android.content.Context
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.os.Environment
import android.text.TextUtils
import android.util.AttributeSet
import android.util.Log
import android.view.View
import android.widget.FrameLayout
import android.widget.LinearLayout
import com.airbnb.lottie.LottieAnimationView
import com.airbnb.lottie.LottieComposition
import com.facebook.drawee.backends.pipeline.Fresco
import com.facebook.drawee.generic.RoundingParams
import com.facebook.drawee.view.SimpleDraweeView
import com.pipipifa.pilaipiwang.R
import com.pipipifa.util.DeviceUtil
import com.ppwang.ppbase.utils.FileUtil
import com.ppwang.ppbase.utils.downloadZip.Constants
import com.ppwang.ppbase.utils.downloadZip.DownloadZipUtils
import com.ppwang.ppbase.utils.downloadZip.Tools
import java.io.File
import java.io.FileInputStream
import java.io.FileNotFoundException

/**
 * @author: wangben
 * @date: 2020/4/22
 */
class PUILottieView : FrameLayout {
    lateinit var mLottieView: LottieAnimationView
    internal var cache = "/data/data/com.pipipifa.pilaipiwang/cache/"

    /**
     * 圆角的图片使用该组件
     */
    lateinit var mAvaterSdv: SimpleDraweeView;

    constructor(context: Context) : super(context) {
        initView(context)
    }

    constructor(context: Context, attrs: AttributeSet?) : super(context, attrs) {
        initView(context)
    }

    constructor(context: Context, attrs: AttributeSet?, defStyleAttr: Int) : super(context, attrs, defStyleAttr) {
        initView(context);
    }

    var onDownLoadClickLister: OnDownLoadClickLister? = null

    open fun OnDownLoadClickLister(clickLister: OnDownLoadClickLister?) {
        this.onDownLoadClickLister = clickLister
    }

    fun initView(context: Context) {
        var view = LinearLayout.inflate(context, R.layout.view_lottie_item_lottie, this)
        mLottieView = view.findViewById(R.id.anim_lottie_view)
        mAvaterSdv = view.findViewById(R.id.sdv_avater)
    }

    fun setLottieView(lottieUrl: String) {
        if (!TextUtils.isEmpty(lottieUrl)) {
            //判断是否下载
            val zipDirPath = FileUtil.getFileName(lottieUrl)
            val dirPath = String.format("%s/%s/", Constants.BLACKTECH_HOT_UPDATE_FILE_PATH, zipDirPath)
            val files = Tools.getFilesInDirectory(dirPath)
            if (null != files && files.size > 0) {
                startAnimZip(mLottieView, getDirPath(zipDirPath!!))
            } else {
                startDownload(lottieUrl, FileUtil.getFileName(lottieUrl))
            }
        }
    }

    fun setImageView(imageUrl: String, radius: Int) {
        mAvaterSdv.visibility = View.VISIBLE
        mLottieView.visibility = View.GONE
        if (!TextUtils.isEmpty(imageUrl)) {
            // 加载图片
            val radius = DeviceUtil.dipToPx(context, radius.toFloat()).toFloat()
            val rp = RoundingParams.fromCornersRadius(radius)
            mAvaterSdv.hierarchy.roundingParams = rp;
            val controller = Fresco.newDraweeControllerBuilder()
                    .setUri(imageUrl)
                    .setAutoPlayAnimations(true)
                    .build();
            mAvaterSdv.controller = controller

        }
    }

    fun setImageViewLayoutParams(mBitMap: Bitmap) {
        mAvaterSdv.setImageBitmap(mBitMap)
    }


    open fun startDownload(zipurl: String, dirPath: String) {
        var utils = DownloadZipUtils()
        utils.DownloadZipUtils(zipurl, dirPath)
        utils.setUpdateProgressListner { code, `object` ->
            //下载完成的回调
            if (code == 200) {
                onDownLoadClickLister?.onLoadComplete()
            }
        }
    }

    /**
     * 显示banner动画
     */
    open fun startAnimZip(lottieAnimationView: LottieAnimationView, url: String) {
        val imageurl = String.format("%s/images", url)
        val json = String.format("%s/data.json", url)
        // 动效图片资源
        val IMAGES_FILES = File(String.format("%s%s", Environment.getExternalStorageDirectory(), imageurl))
        // data.json路径
        val JSON_FILE = File(String.format("%s%s", Environment.getExternalStorageDirectory(), json))
        var fis: FileInputStream? = null
        if (JSON_FILE.exists()) {
            try {
                fis = FileInputStream(JSON_FILE)
            } catch (e: FileNotFoundException) {
                e.printStackTrace()
            }
        }
        if (fis == null || !IMAGES_FILES.exists()) {
            Log.i("huangssh", "动画资源不存在")
            return
        }
        val absolutePath = File(IMAGES_FILES.absolutePath)
        // 设置动画文件夹代理类
        lottieAnimationView.setImageAssetDelegate { asset ->
            val opts = BitmapFactory.Options()
            opts.inScaled = true
            var bitmap: Bitmap? = null
            try {
                bitmap = BitmapFactory.decodeFile(absolutePath.toString() + File.separator + asset.fileName, opts)
            } catch (e: Exception) {
                e.printStackTrace()
            }
            bitmap
        }
        mAvaterSdv.visibility = View.GONE
        mLottieView.visibility = View.VISIBLE
        // 设置动画
        LottieComposition.Factory.fromInputStream(fis) { composition ->
            if (composition != null) {
                lottieAnimationView.setComposition(composition)
            }
            lottieAnimationView.playAnimation()
            lottieAnimationView.loop(true)
        }
    }

    fun getDirPath(dirPath: String): String {
        return cache + dirPath
    }

    interface OnDownLoadClickLister {
        fun onLoadComplete()
    }
}

