package com.pipipifa.pilaipiwang.ui.view.saerchbar

import android.content.Context
import android.graphics.drawable.Drawable
import android.text.Editable
import android.text.TextWatcher
import android.util.AttributeSet
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.widget.EditText
import android.widget.ImageView
import android.widget.LinearLayout
import com.pipipifa.pilaipiwang.R
import com.pipipifa.util.DeviceUtil

class SearchBarView : LinearLayout {

    private lateinit var mLeftIconIv: ImageView
    private lateinit var mRightIconIv: ImageView
    private lateinit var mCleanIv: ImageView
    lateinit var mEditText: EditText

    private var mIsShowLeftIcon = true
    private var mRightIconRes = 0
    private var mHintText = ""
    private var mIsEnable = true

    constructor(context: Context?) : this(context, null)
    constructor(context: Context?, attrs: AttributeSet?) : this(context, attrs, 0)
    constructor(context: Context?, attrs: AttributeSet?, defStyleAttr: Int) : super(context, attrs, defStyleAttr) {
        initAttrs(context!!, attrs, defStyleAttr)
        init(context!!)
    }

    private fun initAttrs(context: Context, attrs: AttributeSet?, defStyleAttr: Int) {
        val ta = context.obtainStyledAttributes(attrs, R.styleable.SearchBarView, defStyleAttr, 0)
        mIsShowLeftIcon = ta.getBoolean(R.styleable.SearchBarView_showSearchIcon, true)
        mRightIconRes = ta.getResourceId(R.styleable.SearchBarView_rigitIconRes, 0)
        mHintText = ta.getString(R.styleable.SearchBarView_hint) ?: ""
        mIsEnable = ta.getBoolean(R.styleable.SearchBarView_enable, true)
        ta.recycle()
    }

    private fun init(context: Context) {
        // 初始化自身
        orientation = HORIZONTAL
        gravity = Gravity.CENTER_VERTICAL
        val paddingLeft = DeviceUtil.dipToPx(context, 10f)
        val paddingRight = DeviceUtil.dipToPx(context, 5f)
        setPadding(paddingLeft, 0, paddingRight, 0)
        setBackgroundResource(R.drawable.bg_corner_fff_radius_18_height_36)
        // 填充视图
        LayoutInflater.from(context).inflate(R.layout.view_comm_search_bar, this, true)
        mLeftIconIv = findViewById(R.id.iv_search_bar_icon)
        mRightIconIv = findViewById(R.id.iv_search_bar_right_icon)
        mCleanIv = findViewById(R.id.iv_search_bar_clean)
        mEditText = findViewById(R.id.et_search_bar_content)
        mEditText.hint = mHintText
        if (mRightIconRes != 0) {
            // 设置了右边icon
            mRightIconIv.setImageResource(mRightIconRes)
            mRightIconIv.visibility = View.VISIBLE
        }
        mEditText.addTextChangedListener(object : TextWatcher {
            override fun afterTextChanged(s: Editable?) {
                if (s != null && s.isNotEmpty()) {
                    mCleanIv.visibility = View.VISIBLE
                    if (mRightIconIv.visibility == View.VISIBLE) {
                        mRightIconIv.visibility = View.GONE
                    }
                } else {
                    mCleanIv.visibility = View.GONE
                    if (mRightIconRes != 0) {
                        mRightIconIv.visibility = View.VISIBLE
                    } else {
                        mRightIconIv.visibility = View.GONE
                    }
                }
            }

            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
            }
        })
        if (!mIsEnable) {
            mEditText.isCursorVisible = false
            mEditText.isFocusable = false
            mEditText.isFocusableInTouchMode = false
        }
        mCleanIv.setOnClickListener {
            mEditText.setText("")
        }

        if (mIsShowLeftIcon) {
            mLeftIconIv.visibility = View.VISIBLE
        } else {
            mLeftIconIv.visibility = View.GONE
        }
    }

    /**
     * 获取搜索编辑款内容
     */
    fun getText(): String = mEditText.text.toString()

    /**
     * 添加文本监听器
     */
    fun addTextChangedListener(watcher: TextWatcher) {
        mEditText.addTextChangedListener(watcher)
    }

    /**
     * 设置hint文本
     */
    fun setHint(hint: String) {
        mEditText.hint = hint
    }

    /**
     * 设置编辑状态
     */
    fun setEditTextEnable(enable: Boolean) {
        if (mIsEnable == enable) {
            return
        }
        mIsEnable = enable
        if (mIsEnable) {
            mEditText.isCursorVisible = true
            mEditText.isFocusable = true
            mEditText.isFocusableInTouchMode = true
        } else {
            mEditText.isCursorVisible = false
            mEditText.isFocusable = false
            mEditText.isFocusableInTouchMode = false
        }
    }

    /**
     * 设置右边按钮点击事件
     */
    fun setOnRightIconClickListener(l: OnClickListener) {
        mRightIconIv.setOnClickListener(l)
    }

}